@@ -12,6 +12,7 @@ import pytest
 
 from pip._internal.req.constructors import install_req_from_line
 from pip._internal.utils.misc import rmtree
+
 from tests.lib import (
     PipTestEnvironment,
     TestData,
@@ -65,10 +66,10 @@ def test_basic_uninstall_distutils(script: PipTestEnvironment) -> None:
     result = script.pip(
         "uninstall", "distutils_install", "-y", expect_stderr=True, expect_error=True
     )
+    assert "Cannot uninstall distutils-install 0.1" in result.stderr
     assert (
-        "Cannot uninstall 'distutils-install'. It is a distutils installed "
-        "project and thus we cannot accurately determine which files belong "
-        "to it which would lead to only a partial uninstall."
+        "It is a distutils installed project and thus we cannot accurately determine "
+        "which files belong to it which would lead to only a partial uninstall."
     ) in result.stderr
 
 
@@ -238,7 +239,6 @@ def test_uninstall_overlapping_package(
     "console_scripts",
     [
         "test_ = distutils_install:test",
-        "test_:test_ = distutils_install:test_test",
         ",test_ = distutils_install:test_test",
         ", = distutils_install:test_test",
     ],
@@ -591,18 +591,16 @@ def test_uninstall_without_record_fails(
             installer_path.write_text(installer + os.linesep)
 
     result2 = script.pip("uninstall", "simple.dist", "-y", expect_error=True)
-    expected_error_message = (
-        "ERROR: Cannot uninstall simple.dist 0.1, RECORD file not found."
-    )
+    assert "Cannot uninstall simple.dist 0.1" in result2.stderr
+    assert "no RECORD file was found for simple.dist" in result2.stderr
     if not isinstance(installer, str) or not installer.strip() or installer == "pip":
-        expected_error_message += (
-            " You might be able to recover from this via: "
-            "'pip install --force-reinstall --no-deps "
-            "simple.dist==0.1'."
+        hint = (
+            "You might be able to recover from this via: "
+            "pip install --force-reinstall --no-deps simple.dist==0.1"
         )
     elif installer:
-        expected_error_message += f" Hint: The package was installed by {installer}."
-    assert result2.stderr.rstrip() == expected_error_message
+        hint = f"The package was installed by {installer}."
+    assert f"hint: {hint}" in result2.stderr
     assert_all_changes(result.files_after, result2, ignore_changes)
 
 
@@ -672,7 +670,7 @@ def test_uninstall_editable_and_pip_install(
     script.assert_not_installed("FSPkg")
 
 
-@pytest.fixture()
+@pytest.fixture
 def move_easy_install_pth(script: PipTestEnvironment) -> Iterator[None]:
     """Move easy-install.pth out of the way for testing easy_install."""
     easy_install_pth = join(script.site_packages_path, "easy-install.pth")
