@@ -80,7 +80,7 @@ def test_make_metadata_file_custom_value_overrides() -> None:
 
 def test_make_metadata_file_custom_contents() -> None:
     value = b"hello"
-    f = default_make_metadata(value=value)
+    f = default_make_metadata(value=value)  # type: ignore[arg-type]
     assert f is not None
     assert f.contents == value
 
